@@ -578,7 +578,7 @@ class Agent(Insight, Channel, Catalog, Dataset):
 
     def get_datacard(self, slug):
 
-        url = self.smart_insight_url + "/definitions/agent/" + self._agentId + "/slug/" + slug
+        url = self.smart_insight_url + "/definitions/insight-slugs/" + slug +"?agentId=" + self._agentId + "&definitionOnly=true"
 
         s = requests.Session()
         s.keep_alive = False
@@ -1419,7 +1419,7 @@ class Askdata(SignUp):
         body = {
             "message": query,
             "language": lang.lower(),
-            "metadata":[],
+            "metadata": [],
             "getRawData": get_raw_data
         }
 
